/**
 * OW2 Util
 * Copyright (C) 2010 Bull S.A.S.
 * Contact: easybeans@ow2.org
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
 * USA
 *
 * --------------------------------------------------------------------------
 * $Id: AuditIDImpl.java 5465 2010-04-21 12:31:45Z benoitf $
 * --------------------------------------------------------------------------
 */

package org.ow2.util.auditreport.impl;

import java.io.Serializable;
import java.util.UUID;

import org.ow2.util.auditreport.api.IAuditID;

/**
 * Implementation of the Audit ID.
 * @author Florent Benoit
 */
public class AuditIDImpl implements IAuditID, Serializable {

    /**
     * Serial version UID.
     */
    private static final long serialVersionUID = 3855603875318289890L;

    /**
     * Parent ID.
     */
    private String parentID = "";

    /**
     * Local count.
     */
    private long localCount = 0L;

    /**
     * ID.
     */
    private String id = "";

    /**
     * Default Constructor.
     */
    public AuditIDImpl() {
    }

    /**
     * Creates an Audit with the given id.
     * @param auditId the given ID
     */
    public AuditIDImpl(final String auditId) {
        this();

        // Split parent and local
        String[] ids = auditId.split(":");
        this.parentID = ids[0];
        String localID = ids[1];
        // there is an ID in the message, store it
        String[] clientID = localID.split("/");
        this.id = clientID[0];
        this.localCount = Integer.valueOf(clientID[1]).longValue();
    }

    /**
     * @return the parent ID.
     */
    public String getParentID() {
        return parentID;
    }

    /**
     * @return the full ID.
     */
    public String getID() {
        return getParentID() + ":" + getLocalID();
    }

    /**
     * @return the local ID.
     */
    public String getLocalID() {
        return id + "/" + localCount;
    }

    /**
     * A call is done on this ID, needs to increment.
     */
    public void increment() {
        localCount++;
    }

    /**
     * Generate a new ID.
     */
    public void generate() {
        this.id = UUID.randomUUID().toString();
    }

    /**
     * Sets the parent ID.
     * @param parentID the given parent ID
     */
    public void setParentID(final String parentID) {
        this.parentID = parentID;
    }

}
