/**
 * OW2 Util
 * Copyright (C) 2010 Bull S.A.S.
 * Contact: easybeans@ow2.org
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
 * USA
 *
 * --------------------------------------------------------------------------
 * $Id: ListeningChecker.java 5360 2010-02-24 14:29:45Z benoitf $
 * --------------------------------------------------------------------------
 */
package org.ow2.util.auditreport.impl.jmx;

import java.util.logging.Level;
import java.util.logging.Logger;

import javax.management.MBeanServer;
import javax.management.NotificationListener;
import javax.management.ObjectName;

/**
 * Thread waiting for JMX registration.
 * @author Mathieu ANCELIN
 */
public class ListeningChecker extends Thread {

    /**
     * Milliseconds to wait.
     */
    private static final int WAITING = 1000;

    /**
     * Logger of the class.
     */
    private Logger logger = Logger.getLogger(ListeningChecker.class.getName());

    /**
     * The JMX object to listen.
     */
    private ObjectName listening;

    /**
     * The listener associated with listening object.
     */
    private NotificationListener listener;

    /**
     * Running flag.
     */
    private boolean running = true;

    /**
     * MBean Server.
     */
    private MBeanServer jmxServer = null;

    /**
     * Constructor.
     * @param listening listened object associated with a listener.
     * @param listener the notification listener associated with listened
     *        object.
     */
    public ListeningChecker(final ObjectName listening, final NotificationListener listener) {
        this.listening = listening;
        this.listener = listener;
    }

    public void setJMXServer(final MBeanServer jmxServer) {
        this.jmxServer = jmxServer;
    }

    /**
     * Wait for the listened object presence in JMX.
     */
    @Override
    public void run() {
        logger.log(Level.INFO, "Waiting for " + listening.getCanonicalName() + " registration ...");
        while (running) {
            try {
                if (jmxServer != null) {
                    if (jmxServer.isRegistered(this.listening)) {
                        jmxServer.addNotificationListener(this.listening, this.listener, null, null);
                        logger.log(Level.INFO, listening.getCanonicalName() + " is now registered for audit logging.");
                        running = false;
                    }
                }
            } catch (Exception ex) {
                logger.log(Level.SEVERE, null, ex);
            }
            try {
                sleep(WAITING);
            } catch (InterruptedException ex) {
                logger.log(Level.SEVERE, null, ex);
            }
        }
    }
}
